@@ -48,7 +48,9 @@ from .parts.folding_range import FoldingRangeProtocolPart
 from .parts.formatting import FormattingProtocolPart
 from .parts.hover import HoverProtocolPart
 from .parts.implementation import ImplementationProtocolPart
+from .parts.linked_editing_ranges import LinkedEditingRangeProtocolPart
 from .parts.references import ReferencesProtocolPart
+from .parts.selection_range import SelectionRangeProtocolPart
 from .parts.semantic_tokens import SemanticTokensProtocolPart
 from .parts.signature_help import SignatureHelpProtocolPart
 from .parts.window import WindowProtocolPart
@@ -81,6 +83,8 @@ class LanguageServerProtocol(JsonRPCProtocol):
     semantic_tokens = ProtocolPartDescriptor(SemanticTokensProtocolPart)
     references = ProtocolPartDescriptor(ReferencesProtocolPart)
     document_highlight = ProtocolPartDescriptor(DocumentHighlightProtocolPart)
+    linked_editing_range = ProtocolPartDescriptor(LinkedEditingRangeProtocolPart)
+    selection_range = ProtocolPartDescriptor(SelectionRangeProtocolPart)
 
     name: Optional[str] = None
     version: Optional[str] = None
