@@ -18,10 +18,10 @@ from typing import (
 )
 
 from ...common.lsp_types import Position
-from ..diagnostics.entities import VariableDefinition
+from ..diagnostics.entities import VariableDefinition, VariableNotFoundDefinition
 from ..diagnostics.library_doc import KeywordDoc, KeywordError
 from ..diagnostics.namespace import LibraryEntry, Namespace
-from ..utils.ast import (
+from ..utils.ast_utils import (
     Token,
     is_not_variable_token,
     iter_over_keyword_names_and_owners,
@@ -239,6 +239,7 @@ class ModelHelperMixin:
         nodes: Optional[List[ast.AST]],
         position: Optional[Position] = None,
         skip_commandline_variables: bool = False,
+        return_not_found: bool = False,
     ) -> AsyncGenerator[Tuple[Token, VariableDefinition], Any]:
         from robot.api.parsing import Token as RobotToken
 
@@ -248,16 +249,31 @@ class ModelHelperMixin:
             if variable_started:
                 if toknum == python_token.NAME:
                     var = await namespace.find_variable(
-                        f"${{{tokval}}}", nodes, position, skip_commandline_variables=skip_commandline_variables
+                        f"${{{tokval}}}",
+                        nodes,
+                        position,
+                        skip_commandline_variables=skip_commandline_variables,
+                        ignore_error=True,
+                    )
+                    sub_token = RobotToken(
+                        expression.type,
+                        tokval,
+                        expression.lineno,
+                        expression.col_offset + tokcol,
+                        expression.error,
                     )
                     if var is not None:
-                        yield RobotToken(
-                            expression.type,
+                        yield sub_token, var
+                    elif return_not_found:
+                        yield sub_token, VariableNotFoundDefinition(
+                            sub_token.lineno,
+                            sub_token.col_offset,
+                            sub_token.lineno,
+                            sub_token.end_col_offset,
+                            namespace.source,
                             tokval,
-                            expression.lineno,
-                            expression.col_offset + tokcol,
-                            expression.error,
-                        ), var
+                            sub_token,
+                        )
                 variable_started = False
             if toknum == python_token.ERRORTOKEN and tokval == "$":
                 variable_started = True
@@ -331,10 +347,19 @@ class ModelHelperMixin:
         nodes: Optional[List[ast.AST]],
         position: Optional[Position] = None,
         skip_commandline_variables: bool = False,
+        return_not_found: bool = False,
     ) -> AsyncGenerator[Tuple[Token, VariableDefinition], Any]:
         from robot.api.parsing import Token as RobotToken
         from robot.variables.search import contains_variable, search_variable
 
+        def is_number(name: str) -> bool:
+            from robot.variables.finders import NOT_FOUND, NumberFinder
+
+            if name.startswith("$"):
+                finder = NumberFinder()
+                return bool(finder.find(name) != NOT_FOUND)
+            return False
+
         async def iter_token(
             to: Token, ignore_errors: bool = False
         ) -> AsyncGenerator[Union[Token, Tuple[Token, VariableDefinition]], Any]:
@@ -352,8 +377,20 @@ class ModelHelperMixin:
                             nodes,
                             position,
                             skip_commandline_variables=skip_commandline_variables,
+                            return_not_found=return_not_found,
                         ):
                             yield v
+                    elif base == "" and return_not_found:
+                        yield sub_token, VariableNotFoundDefinition(
+                            sub_token.lineno,
+                            sub_token.col_offset,
+                            sub_token.lineno,
+                            sub_token.end_col_offset,
+                            namespace.source,
+                            sub_token.value,
+                            sub_token,
+                        )
+                        return
 
                     if contains_variable(base, "$@&%"):
                         async for sub_token_or_var in iter_token(
@@ -378,12 +415,15 @@ class ModelHelperMixin:
                 sub_token = token_or_var
                 name = sub_token.value
                 var = await namespace.find_variable(
-                    name, nodes, position, skip_commandline_variables=skip_commandline_variables
+                    name, nodes, position, skip_commandline_variables=skip_commandline_variables, ignore_error=True
                 )
                 if var is not None:
                     yield strip_variable_token(sub_token), var
                     continue
 
+                if is_number(sub_token.value):
+                    continue
+
                 if (
                     sub_token.type == RobotToken.VARIABLE
                     and sub_token.value[:1] in "$@&%"
@@ -395,12 +435,41 @@ class ModelHelperMixin:
                         base_name, _ = match.groups()
                         name = f"{name[0]}{{{base_name.strip()}}}"
                         var = await namespace.find_variable(
-                            name, nodes, position, skip_commandline_variables=skip_commandline_variables
+                            name,
+                            nodes,
+                            position,
+                            skip_commandline_variables=skip_commandline_variables,
+                            ignore_error=True,
                         )
+                        sub_sub_token = RobotToken(sub_token.type, name, sub_token.lineno, sub_token.col_offset)
                         if var is not None:
-                            yield strip_variable_token(
-                                RobotToken(sub_token.type, name, sub_token.lineno, sub_token.col_offset)
-                            ), var
+                            yield strip_variable_token(sub_sub_token), var
+                            continue
+                        if is_number(name):
+                            continue
+                        elif return_not_found:
+                            if contains_variable(sub_token.value[2:-1]):
+                                continue
+                            else:
+                                yield strip_variable_token(sub_sub_token), VariableNotFoundDefinition(
+                                    sub_sub_token.lineno,
+                                    sub_sub_token.col_offset,
+                                    sub_sub_token.lineno,
+                                    sub_sub_token.end_col_offset,
+                                    namespace.source,
+                                    name,
+                                    sub_sub_token,
+                                )
+                if return_not_found:
+                    yield strip_variable_token(sub_token), VariableNotFoundDefinition(
+                        sub_token.lineno,
+                        sub_token.col_offset,
+                        sub_token.lineno,
+                        sub_token.end_col_offset,
+                        namespace.source,
+                        sub_token.value,
+                        sub_token,
+                    )
             else:
                 yield token_or_var
 
